@@ -46,7 +46,8 @@ gb_eval_add (const GBValue *l, const GBValue *r)
 	g_return_val_if_fail (l != NULL, NULL);
 	g_return_val_if_fail (r != NULL, NULL);
 
-	if (r->type < l->type) {
+	if (gb_value_from_gtk_type (r->gtk_type) <
+	    gb_value_from_gtk_type (l->gtk_type)) {
 		const GBValue *tmp = l;
 		l = r;
 		r = tmp;
@@ -66,7 +67,8 @@ gb_eval_mult (const GBValue *l, const GBValue *r)
 	g_return_val_if_fail (l != NULL, NULL);
 	g_return_val_if_fail (r != NULL, NULL);
 
-	if (r->type < l->type) {
+	if (gb_value_from_gtk_type (r->gtk_type) <
+	    gb_value_from_gtk_type (l->gtk_type)) {
 		const GBValue *tmp = l;
 		l = r;
 		r = tmp;
@@ -128,8 +130,8 @@ gb_eval_concat (const GBValue *l, const GBValue *r)
 	g_return_val_if_fail (l != NULL, NULL);
 	g_return_val_if_fail (r != NULL, NULL);
 
-	if (l->type == GB_VALUE_NULL &&
-	    r->type == GB_VALUE_NULL)
+	if (l->gtk_type == gb_gtk_type_from_value (GB_VALUE_NULL) &&
+	    r->gtk_type == gb_gtk_type_from_value (GB_VALUE_NULL))
 		return gb_value_new_null ();
 
 	str = (GString *)gb_value_get_as_string (l);
@@ -148,12 +150,12 @@ gb_eval_eqv (const GBValue *l, const GBValue *r)
 	g_return_val_if_fail (l != NULL, NULL);
 	g_return_val_if_fail (r != NULL, NULL);
 
-	if (l->type == GB_VALUE_NULL &&
-	    r->type == GB_VALUE_NULL)
+	if (l->gtk_type == gb_gtk_type_from_value (GB_VALUE_NULL) &&
+	    r->gtk_type == gb_gtk_type_from_value (GB_VALUE_NULL))
 		return gb_value_new_null ();
 	
-	if (l->type == GB_VALUE_BOOLEAN &&
-	    r->type == GB_VALUE_BOOLEAN) {
+	if (l->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN) &&
+	    r->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN)) {
 		if (l->v.bool == r->v.bool)
 			return gb_value_new_boolean (GBTrue);
 		else
@@ -174,20 +176,22 @@ gb_eval_and (const GBValue *l, const GBValue *r)
 	g_return_val_if_fail (l != NULL, NULL);
 	g_return_val_if_fail (r != NULL, NULL);
 
-	if (l->type == GB_VALUE_BOOLEAN && /* Most common we hope */
-	    r->type == GB_VALUE_BOOLEAN)
+	if (l->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN) &&
+	    r->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN)) /* Most common we hope */
 		return gb_value_new_boolean (l->v.bool && r->v.bool);
 
-	if (l->type == GB_VALUE_NULL &&
-	    r->type == GB_VALUE_NULL)
+	if (l->gtk_type == gb_gtk_type_from_value (GB_VALUE_NULL) &&
+	    r->gtk_type == gb_gtk_type_from_value (GB_VALUE_NULL))
 		return gb_value_new_null ();
 
-	if ((l->type == GB_VALUE_NULL &&  /* Boolean and Null: ug ! */
-	     r->type == GB_VALUE_BOOLEAN) ||
-	    (l->type == GB_VALUE_BOOLEAN &&
-	     r->type == GB_VALUE_NULL)) {
-		if ((l->type == GB_VALUE_BOOLEAN && l->v.bool) ||
-		    (r->type == GB_VALUE_BOOLEAN && r->v.bool))
+	if ((l->gtk_type == gb_gtk_type_from_value (GB_VALUE_NULL) &&
+	     r->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN)) ||
+	    (r->gtk_type == gb_gtk_type_from_value (GB_VALUE_NULL) &&
+	     l->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN))) { /* Boolean and Null: ug ! */
+
+		if ((l->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN) && l->v.bool) ||
+		    (r->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN) && r->v.bool))
+
 			return gb_value_new_null ();
 		else
 			return gb_value_new_boolean (GBFalse);
@@ -195,7 +199,7 @@ gb_eval_and (const GBValue *l, const GBValue *r)
 	    
 	ll = gb_value_get_as_long (l);
 	rl = gb_value_get_as_long (r);
-
+	
 	return gb_value_new_long (ll & rl);
 }
 
@@ -207,12 +211,12 @@ gb_eval_or (const GBValue *l, const GBValue *r)
 	g_return_val_if_fail (l != NULL, NULL);
 	g_return_val_if_fail (r != NULL, NULL);
 
-	if (l->type == GB_VALUE_BOOLEAN && /* Most common we hope */
-	    r->type == GB_VALUE_BOOLEAN)
+	if (l->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN) &&
+	    r->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN)) /* Most common we hope */
 		return gb_value_new_boolean (l->v.bool || r->v.bool);
 
-	if (l->type == GB_VALUE_NULL ||
-	    r->type == GB_VALUE_NULL) {
+	if (l->gtk_type == gb_gtk_type_from_value (GB_VALUE_NULL) ||
+	    r->gtk_type == gb_gtk_type_from_value (GB_VALUE_NULL)) {
 		g_warning ("Fixme: is this correct ?");
 		return gb_value_new_null ();
 	}
@@ -231,12 +235,12 @@ gb_eval_xor (const GBValue *l, const GBValue *r)
 	g_return_val_if_fail (l != NULL, NULL);
 	g_return_val_if_fail (r != NULL, NULL);
 
-	if (l->type == GB_VALUE_BOOLEAN && /* Most common we hope */
-	    r->type == GB_VALUE_BOOLEAN)
+	if (l->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN) &&
+	    r->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN)) /* Most common we hope */
 		return gb_value_new_boolean (l->v.bool != r->v.bool);
 
-	if (l->type == GB_VALUE_NULL ||
-	    r->type == GB_VALUE_NULL)
+	if (l->gtk_type == gb_gtk_type_from_value (GB_VALUE_NULL) ||
+	    r->gtk_type == gb_gtk_type_from_value (GB_VALUE_NULL))
 		return gb_value_new_null ();
 	    
 	ll = gb_value_get_as_long (l);
@@ -256,37 +260,37 @@ gb_eval_imp (const GBValue *l, const GBValue *r)
 /* FIXME: Imp users have damaged brains; commutativity is golden. */
 
 	/* This really sucks */
-	if (l->type == GB_VALUE_BOOLEAN && l->v.bool) {
+	if (l->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN) && l->v.bool) {
 
-		if (r->type == GB_VALUE_BOOLEAN && l->v.bool)
+		if (r->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN) && l->v.bool)
 			return gb_value_new_boolean (GBTrue);
 
-		else if (r->type == GB_VALUE_BOOLEAN && !l->v.bool)
+		else if (r->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN) && !l->v.bool)
 			return gb_value_new_boolean (GBFalse);
 
-		else if (r->type == GB_VALUE_NULL)
+		else if (r->gtk_type == gb_gtk_type_from_value (GB_VALUE_NULL))
 			return gb_value_new_null ();
 
-	} else if (l->type == GB_VALUE_BOOLEAN && !l->v.bool) {
+	} else if (l->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN) && !l->v.bool) {
 
-		if (r->type == GB_VALUE_BOOLEAN && l->v.bool)
+		if (r->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN) && l->v.bool)
 			return gb_value_new_boolean (GBTrue);
 
-		else if (r->type == GB_VALUE_BOOLEAN && !l->v.bool)
+		else if (r->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN) && !l->v.bool)
 			return gb_value_new_boolean (GBTrue);
 
-		else if (r->type == GB_VALUE_NULL)
+		else if (r->gtk_type == gb_gtk_type_from_value (GB_VALUE_NULL))
 			return gb_value_new_boolean (GBTrue);
 
-	} else if (l->type == GB_VALUE_NULL) {
+	} else if (l->gtk_type == gb_gtk_type_from_value (GB_VALUE_NULL)) {
 
-		if (r->type == GB_VALUE_BOOLEAN && l->v.bool)
+		if (r->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN) && l->v.bool)
 			return gb_value_new_boolean (GBTrue);
 
-		else if (r->type == GB_VALUE_BOOLEAN && !l->v.bool)
+		else if (r->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN) && !l->v.bool)
 			return gb_value_new_null ();
 
-		else if (r->type == GB_VALUE_NULL)
+		else if (r->gtk_type == gb_gtk_type_from_value (GB_VALUE_NULL))
 			return gb_value_new_null ();
 	}
 	    
@@ -307,10 +311,10 @@ gb_eval_not (const GBValue *v)
 
 	g_return_val_if_fail (v != NULL, NULL);
 
-	if (v->type == GB_VALUE_NULL)
+	if (v->gtk_type == gb_gtk_type_from_value (GB_VALUE_NULL))
 		return gb_value_new_null ();
 
-	if (v->type == GB_VALUE_BOOLEAN)
+	if (v->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN))
 		return gb_value_new_boolean (!v->v.bool);
 	
 	vl = gb_value_get_as_long (v);
@@ -323,7 +327,7 @@ gb_eval_neg (const GBValue *v)
 {
 	g_return_val_if_fail (v != NULL, NULL);
 
-	switch (v->type) {
+	switch (gb_value_from_gtk_type (v->gtk_type)) {
 
 	case GB_VALUE_NULL:
 		return gb_value_new_null ();
@@ -526,8 +530,8 @@ gb_eval_compare (GBEvalContext *ec,
 	g_return_val_if_fail (r, GBFalse);
 	g_return_val_if_fail (GB_EXPR_COMPARE(t), GBFalse);
 
-	if (l->type == GB_VALUE_STRING &&
-	    r->type == GB_VALUE_STRING) {
+	if (l->gtk_type == gb_gtk_type_from_value (GB_VALUE_STRING) &&
+	    r->gtk_type == gb_gtk_type_from_value (GB_VALUE_STRING)) {
 		GBLong l_num;
 		GBLong r_num;
 
@@ -564,19 +568,19 @@ gb_eval_compare (GBEvalContext *ec,
 			g_warning ("Extra unhandled compare type added");
 			break;
 		}
-	} else if ((gb_value_is_integer (l) || l->type == GB_VALUE_BOOLEAN) &&
-		   (gb_value_is_integer (r) || r->type == GB_VALUE_BOOLEAN)) {
+	} else if ((gb_value_is_integer (l) || l->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN)) &&
+		   (gb_value_is_integer (r) || r->gtk_type == gb_gtk_type_from_value (GB_VALUE_BOOLEAN))) {
 
 		GBValue *v;
 		GBLong   l_num;
 		GBLong   r_num;
 
-		v = gb_value_promote (ec, l, GB_VALUE_LONG);
+		v = gb_value_promote (ec, gb_gtk_type_from_value (GB_VALUE_LONG), l);
 		if (!v)
 			return FALSE;
 		l_num = v->v.l;
 
-		v = gb_value_promote (ec, r, GB_VALUE_LONG);
+		v = gb_value_promote (ec, gb_gtk_type_from_value (GB_VALUE_LONG), r);
 		if (!v)
 			return FALSE;
 		r_num = v->v.l;
@@ -614,13 +618,13 @@ gb_eval_compare (GBEvalContext *ec,
 		GBDouble l_num;
 		GBDouble r_num;
 
-		v = gb_value_promote (ec, l, GB_VALUE_DOUBLE);
+		v = gb_value_promote (ec, gb_gtk_type_from_value (GB_VALUE_DOUBLE), l);
 		if (!v)
 			return FALSE;
 		l_num = v->v.d;
 		gb_value_destroy (v);
 
-		v = gb_value_promote (ec, r, GB_VALUE_DOUBLE);
+		v = gb_value_promote (ec, gb_gtk_type_from_value (GB_VALUE_DOUBLE), r);
 		if (!v)
 			return FALSE;
 		r_num = v->v.d;
@@ -676,11 +680,11 @@ gb_eval_binary (GBEvalContext *ec,
 
 	/* Basic type checks */
  	if (GB_EXPR_BINARY_NUMERIC (t)) {
-		switch (l->type) {
+		switch (gb_value_from_gtk_type (l->gtk_type)) {
 		case GB_VALUE_NUMBER:
 			break;
 		default:
-			switch (r->type) {
+			switch (gb_value_from_gtk_type (r->gtk_type)) {
 			case GB_VALUE_NUMBER:
 				break;
 			default:
@@ -830,7 +834,7 @@ gb_eval_context_eval (GBEvalContext *ec,
 
 		gb_value_destroy (v);
 	} else if (e->type == GB_EXPR_VALUE) {
-		switch (e->parm.value->type) {
+		switch (gb_value_from_gtk_type (e->parm.value->gtk_type)) {
 		case GB_VALUE_NUMBER:
 			val = gb_value_copy (ec, e->parm.value);
 			break;
@@ -838,7 +842,7 @@ gb_eval_context_eval (GBEvalContext *ec,
 		case GB_VALUE_STRING:
 			if ((e->parm.value->v.s->str[0] == '"')     &&
 			     strstr(e->parm.value->v.s->str, "\":")    ) {
-				val = gb_eval_frx (ec ,e->parm.value);
+				val = gb_eval_frx (ec, e->parm.value);
 			} else
 				val = gb_value_copy (ec, e->parm.value);
 			break;
