@@ -252,7 +252,12 @@ gb_obj_ref_new (char const *name, gboolean method,
 	GBObjRef *res;
 
 	res = g_new (GBObjRef, 1);
-	res->name   = g_strdup (name);
+
+	if (name)
+		res->name = g_strdup (name);
+	else
+		res->name = NULL;
+
 	res->method = method;
 	res->parms  = g_slist_reverse (parms);
 
