@@ -8,7 +8,6 @@
  * Copyright 2000, Helix Code Inc.
  */
 #include <math.h>
-#include <setjmp.h>
 
 #include <gbrun/gbrun.h>
 #include <gbrun/gbrun-array.h>
@@ -19,8 +18,6 @@
 
 #undef ARRAY_DEBUG
 
-#define PRIV(o) ((GBRunArray *)gb_object_get_priv ((o), gbrun_array_get_class ()))
-
 typedef struct {
 	GBLong min, max;
 } GBRunARange;
