@@ -18,26 +18,26 @@ typedef struct _GBRunFileHandle GBRunFileHandle;
 
 
 GBValue *gbrun_func_eof         (GBRunEvalContext *ec,
-				 GBObject         *object,
+				 GBRunObject      *object,
 				 GBValue         **args);
 GBValue *gbrun_func_freefile    (GBRunEvalContext *ec,
-				 GBObject         *object,
+				 GBRunObject      *object,
 				 GBValue         **args);
 GBValue *gbrun_func_loc         (GBRunEvalContext *ec,
-				 GBObject         *object,
+				 GBRunObject      *object,
 				 GBValue         **args);
 GBValue *gbrun_func_lof         (GBRunEvalContext *ec,
-				 GBObject         *object,
+				 GBRunObject      *object,
 				 GBValue         **args);
 GBValue *gbrun_func_seek        (GBRunEvalContext *ec,
-				 GBObject         *object,
+				 GBRunObject      *object,
 				 GBValue         **args);
 GBValue *gbrun_func_loc         (GBRunEvalContext *ec,
-				 GBObject         *object,
+				 GBRunObject      *object,
+				 GBValue         **args);
+GBValue *gbrun_func_lof         (GBRunEvalContext *ec,
+				 GBRunObject      *object,
 				 GBValue         **args);
-GBValue *gbrun_func_lof          (GBRunEvalContext *ec,
-				  GBObject         *object,
-				  GBValue         **args);
 
 
 gboolean gbrun_stmt_open        (GBRunEvalContext *ec, const GBStatement *stmt);
