@@ -20,6 +20,7 @@
 #include <gbrun/gbrun-statement.h>
 #include <gbrun/gbrun-project.h>
 #include <gbrun/gbrun-global.h>
+#include <gbrun/gbrun-collection.h>
 
 #undef VB_METHOD_DEBUG
 #undef VB_INIT_DEBUG
@@ -35,7 +36,8 @@ struct _GBRunObjectPrivateClass {
 
 	GSList *properties;
 
-	GSList *methods;
+	GBRunObjMethod *default_method;
+	GSList         *methods;
 };
 
 static void
@@ -472,6 +474,13 @@ gbrun_object_get_method (GBRunObjectClass *klass,
 	for (i = klass->priv->classes; i; i = i->next) {
 		GBRunObjectClass *cur_class = i->data;
 
+		if (!name) {
+			if (cur_class->priv->default_method)
+				return cur_class->priv->default_method;
+			else
+				continue;
+		}
+
 /*		g_warning ("Searching class of type '%s' for '%s'",
 			   gtk_type_name (GTK_OBJECT_CLASS (cur_class)->type),
 			   name);*/
@@ -487,6 +496,17 @@ gbrun_object_get_method (GBRunObjectClass *klass,
 	return NULL;
 }
 
+
+void
+gbrun_object_set_default_method (GBRunObjectClass *klass,
+				 const char       *desc)
+{
+	g_return_if_fail (klass != NULL);
+
+	klass->priv->default_method = 
+		gbrun_object_get_method (klass, desc);
+}
+
 GSList *
 gbrun_object_get_methods (GBRunObjectClass *klass)
 {
@@ -509,12 +529,14 @@ typedef struct {
 	GtkType type;
 	int     idx;
 	char   *name;
+	int     flags;
 } GBRunObjectProperty;
 
 static GBRunObjectProperty *
 gbrun_object_get_property (GBRunObjectClass  *klass,
 			   const char        *name,
-			   GBRunObjectClass **on_class)
+			   GBRunObjectClass **on_class,
+			   GBRunPropertyType  flags)
 {
 	GSList *l, *i;
 
@@ -527,8 +549,13 @@ gbrun_object_get_property (GBRunObjectClass  *klass,
 
 		for (l = cur_class->priv->properties; l; l = l->next) {
 			GBRunObjectProperty *prop = l->data;
-			
-			if (!g_strcasecmp (prop->name, name))
+
+/*			g_warning ("is '%s' == '%s' && %d:%d (%d)",
+				   prop->name, name, prop->flags, flags,
+				   prop->flags & flags);*/
+
+			if ((prop->flags & flags) &&
+			    !g_strcasecmp (prop->name, name))
 				return prop;
 		}
 	}
@@ -538,10 +565,11 @@ gbrun_object_get_property (GBRunObjectClass  *klass,
 }
 
 void
-gbrun_object_add_property (GBRunObjectClass *klass,
-			   const char       *name,
-			   GtkType           type,
-			   int               idx)
+gbrun_object_add_property_full (GBRunObjectClass *klass,
+				const char       *name,
+				GtkType           type,
+				int               idx,
+				GBRunPropertyType flags)
 {
 	GBRunObjectProperty *prop;
 
@@ -550,21 +578,36 @@ gbrun_object_add_property (GBRunObjectClass *klass,
 
 	prop = g_new0 (GBRunObjectProperty, 1);
 
-	prop->type = type;
-	prop->name = g_strdup (name);
-	prop->idx  = idx;
+	prop->type  = type;
+	prop->name  = g_strdup (name);
+	prop->idx   = idx;
+	prop->flags = flags;
 
 	klass->priv->properties =
 		g_slist_prepend (klass->priv->properties, prop);
 }
 
+void
+gbrun_object_add_property (GBRunObjectClass *klass,
+			   const char       *name,
+			   GtkType           type,
+			   int               idx)
+{
+	gbrun_object_add_property_full (
+		klass, name, type, idx,
+		GBRUN_PROPERTY_READABLE | 
+		GBRUN_PROPERTY_WRITEABLE);
+}
+
 gboolean
 gbrun_object_has_property (GBRunObjectClass *klass,
-			   const char       *name)
+			   const char       *name,
+			   GBRunPropertyType type)
 {
 	GBRunObjectClass *dummy;
 
-	return gbrun_object_get_property (klass, name, &dummy) != NULL;
+	return gbrun_object_get_property (
+		klass, name, &dummy, type) != NULL;
 }
 
 static GBValue *
@@ -882,7 +925,8 @@ gbrun_object_assign (GBEvalContext  *ec,
 	}
 
 	prop = gbrun_object_get_property (
-		GBRUN_OBJECT_GET_CLASS (object), ref->name, &klass);
+		GBRUN_OBJECT_GET_CLASS (object), ref->name,
+		&klass, GBRUN_PROPERTY_WRITEABLE);
 
 	if (!prop) {
 		if (!try_assign)
@@ -906,6 +950,31 @@ gbrun_object_assign (GBEvalContext  *ec,
 	return ret;
 }
 
+static GBValue *
+chain_deref_to_value (GBEvalContext  *gb_ec,
+		      GBValue        *val,
+		      const GBObjRef *ref,
+		      gboolean        try_deref)
+{
+	GBValue *ret = NULL;
+
+	if (GB_IS_AN_OBJECT (val->gtk_type)) {
+		GBObjRef newref;
+		
+		newref = *ref;
+		newref.name = NULL;
+		ret = gb_object_deref (
+			gb_ec, val->v.obj, &newref, try_deref);
+	} else
+		gb_eval_exception_firev (
+			gb_ec, "Cannot use parameters on '%s'",
+			ref->name);
+
+	gb_value_destroy (val);
+
+	return ret;
+}
+
 static GBValue *
 gbrun_object_deref (GBEvalContext  *gb_ec,
 		    GBObject       *obj,
@@ -915,107 +984,113 @@ gbrun_object_deref (GBEvalContext  *gb_ec,
 	GBRunEvalContext *ec;
 	GBValue          *val = NULL;
 	GBRunObjMethod   *m;
+	GBRunObjectClass *klass;
 
 	g_return_val_if_fail (obj != NULL, NULL);
 
 	ec = GBRUN_EVAL_CONTEXT (gb_ec);
 
-/*	g_warning ("Object deref '%s' method '%d' params: %d",
-	ref->name, ref->method, g_slist_length (ref->parms));*/
+/*	g_warning ("Object '%s' deref '%s' method '%d' params: %d",
+		   gtk_type_name (GTK_OBJECT (obj)->klass->type),
+		   ref->name, ref->method, g_slist_length (ref->parms));*/
 
 	/* 1. See if we have an object variable */
 	if ((val = gbrun_object_var_get (GBRUN_EVAL_CONTEXT (ec),
 					 GBRUN_OBJECT (obj),
 					 ref->name))) {
-		if (ref->parms) { /* Chain to array dereference */
-			if (GB_IS_AN_OBJECT (val->gtk_type)) {
-				GBObjRef newref;
-				GBValue *ret;
-
-				newref = *ref;
-				newref.name = NULL;
-				ret = gb_object_deref (
-					gb_ec, val->v.obj, &newref, try_deref);
-				gb_value_destroy (val);
-
-				return ret;
-			} else {
-				gb_value_destroy (val);
-
-				if (try_deref)
-					goto check_method;
-				else
-					gbrun_exception_firev (
-						ec,
-						"Cannot use parameters on '%s'", ref->name);
-				return NULL;
-			}
-		} else
+		if (ref->parms)
+			return chain_deref_to_value (
+				gb_ec, val, ref, try_deref);
+		else
 			return val;
 	}
 
- check_method:
+	klass = GBRUN_OBJECT_GET_CLASS (obj);
+
 	/* 2. See if we have a method */
-	if ( !(m = gbrun_object_get_method (
-		GBRUN_OBJECT_GET_CLASS (obj), ref->name)) ) {
+	if ((m = gbrun_object_get_method (klass, ref->name))) {
+		GBObjRef parmref;
+		GSList  *parms;
 
-		/* 3. Fall back to an argument */
-		if (!ref->method && !ref->parms) {
-			GBRunObjectProperty *prop;
-			GBRunObjectClass    *klass;
-
-			if (!obj)
-				return NULL;
-
-			prop = gbrun_object_get_property (
-				GBRUN_OBJECT_GET_CLASS (obj),
-				ref->name, &klass);
-
-			if (!prop) {
-				if (!try_deref)
-					gbrun_exception_firev (
-						ec, "No readable property '%s' on object '%s'",
-						ref->name, gbrun_object_name (GBRUN_OBJECT (obj)));
-				return NULL;
-			}
-
-			return klass->get_arg (ec, GBRUN_OBJECT (obj), prop->idx);
-
-		} else {
+		if (ec->flags & m->mask) {
 			if (!try_deref)
 				gbrun_exception_firev (
-					ec, "No '%s' method / function", ref->name);
+					ec, "Security block on function '%s'",
+					ref->name);
 			return NULL;
 		}
-	}
 
-	if (ec->flags & m->mask) {
-		if (!try_deref)
-			gbrun_exception_firev (
-				ec, "Security block on function '%s'", ref->name);
-		return NULL;
-	}
+		parmref = *ref;
+		parmref.name = m->name; /* Might be a default method */
 
-	/*
-	 * FIXME: what if the method doesn't take
-	 * parameters and returns an array ?
-	 */
-	switch (m->type) {
+		parms = ref->parms;
 
-	case GBRUN_METHOD_ARG:
-		val = gbrun_method_invoke_arg (
-			ec, GBRUN_OBJECT (obj), m, ref);
-		break;
+		/* This copes with no-arg functions that return Arrays etc. */
+		if (m->max_args == 0)
+			parmref.parms = NULL;
+		else
+			parms = NULL;
 
-	case GBRUN_METHOD_VAR:
-		val = gbrun_method_invoke_var (
-			ec, GBRUN_OBJECT (obj), m, ref);
-		break;
+		switch (m->type) {
+			
+		case GBRUN_METHOD_ARG:
+			val = gbrun_method_invoke_arg (
+				ec, GBRUN_OBJECT (obj), m, &parmref);
+			break;
+			
+		case GBRUN_METHOD_VAR:
+			val = gbrun_method_invoke_var (
+				ec, GBRUN_OBJECT (obj), m, &parmref);
+			break;
+			
+		case GBRUN_METHOD_VB:
+			val = gbrun_method_invoke_vb  (
+				ec, GBRUN_OBJECT (obj), m, &parmref);
+			break;
+		}
 
-	case GBRUN_METHOD_VB:
-		val = gbrun_method_invoke_vb  (
-			ec, GBRUN_OBJECT (obj), m, ref);
-		break;
+		if (parms) {
+			parmref.parms = parms;
+
+			if (val && GB_IS_AN_OBJECT (val->gtk_type))
+				val = chain_deref_to_value (
+					gb_ec, val, &parmref, try_deref);
+			else {
+				if (!try_deref)
+					gbrun_exception_firev (
+						ec, "Too many arguments to '%s'",
+						ref->name);
+				if (val)
+					gb_value_destroy (val);
+
+				val = NULL;
+			}
+		}
+
+ 	} else { /* 3. Fall back to an argument */
+		GBRunObjectProperty *prop;
+
+		if (!obj)
+			g_assert_not_reached ();
+
+		prop = gbrun_object_get_property (
+			GBRUN_OBJECT_GET_CLASS (obj),
+			ref->name, &klass,
+			GBRUN_PROPERTY_READABLE);
+		
+		if (!prop) {
+			if (!try_deref)
+				gbrun_exception_firev (
+					ec, "No readable property '%s' on object '%s'",
+					ref->name, gbrun_object_name (GBRUN_OBJECT (obj)));
+			return NULL;
+		}
+		
+		val = klass->get_arg (ec, GBRUN_OBJECT (obj), prop->idx);
+
+		if (val && ref->parms)
+			val = chain_deref_to_value (
+				gb_ec, val, ref, try_deref);
 	}
 
 	return val;
@@ -1193,6 +1268,7 @@ void
 gbrun_object_init (GBEvalContext *ec)
 {
 	gbrun_global_get ();
+	gbrun_collection_get_type ();
 }
 
 void 
