@@ -49,6 +49,11 @@ struct _GBRunObjectClass {
 			     int                property);
 };
 
+typedef enum {
+	GBRUN_PROPERTY_READABLE  = 0x1,
+	GBRUN_PROPERTY_WRITEABLE = 0x2
+} GBRunPropertyType;
+
 struct _GBRunObjMethod {
 	char             *name;
 	GSList           *args;
@@ -75,13 +80,20 @@ GtkType           gbrun_object_subclass        (GtkType           parent,
 GtkType           gbrun_object_subclass_simple (GtkType           parent,
 						const char      *vb_name);
 
-void              gbrun_object_add_property    (GBRunObjectClass *klass,
-						const char       *name,
-						GtkType           type,
-						int               idx);
+void              gbrun_object_add_property      (GBRunObjectClass *klass,
+						  const char       *name,
+						  GtkType           type,
+						  int               idx);
+
+void              gbrun_object_add_property_full (GBRunObjectClass *klass,
+						  const char       *name,
+						  GtkType           type,
+						  int               idx,
+						  GBRunPropertyType flags);
 
 gboolean          gbrun_object_has_property    (GBRunObjectClass *klass,
-						const char       *name);
+						const char       *name,
+						GBRunPropertyType type);
 
 void              gbrun_object_add_variables   (GBRunEvalContext *ec,
 						GBRunObjectClass *klass,
@@ -95,6 +107,9 @@ void              gbrun_object_add_method_arg   (GBRunObjectClass     *klass,
 						 const char           *desc,
 						 GBRunMethodArg       *method);
 
+void              gbrun_object_set_default_method (GBRunObjectClass   *klass,
+						   const char         *desc);
+
 void              gbrun_object_add_routine      (GBRunObjectClass     *klass,
 						 GBRoutine            *routine);
 
