@@ -92,7 +92,9 @@ gbrun_objref_deref (GBRunEvalContext *ec,
 
 			if ((ret = gb_object_deref (GB_EVAL_CONTEXT (ec),
 						    GB_OBJECT (l->data),
-						    ref, TRUE))) {
+						    ref, TRUE)) ||
+			    gbrun_eval_context_exception (ec)) {
+
 				g_slist_free (try);
 				return ret;
 			}
@@ -183,6 +185,12 @@ gbrun_eval_assign (GBRunEvalContext *ec,
 			g_slist_free (try);
 			return TRUE;
 		}
+
+		if (gbrun_eval_context_exception (ec)) {
+			g_slist_free (try);
+			return FALSE;
+		}
+		
 	}
 	g_slist_free (try);
 
