@@ -62,6 +62,9 @@ typedef GBValue *(GBRunMethodArg) (GBRunEvalContext  *context,
 typedef struct _GBRunArray      GBRunArray;
 typedef struct _GBRunArrayClass GBRunArrayClass;
 
+/* gbrun-collection.h */
+typedef struct _GBRunCollection GBRunCollection;
+
 /* gbrun-global.h */
 typedef struct _GBRunGlobal      GBRunGlobal;
 typedef struct _GBRunGlobalClass GBRunGlobalClass;
