@@ -27,45 +27,6 @@ typedef struct {
 	GtkJustification alignment;
 } GBRunCheckBox;
 
-/*
- * _GBECheckBox defines a VB Command Checkbox
- *
- * back_color		Specifies the command checkbox's background color.
- * cancel	 	Determines whether the command checkbox gets a Click
- *			event if the user presses ESC.
- * caption		The text that appears on the command checkbox.
- * def_resp		Determines if the command checkbox respond to an Enter
- *			keypress even if another control has the focus.
- * enabled		Determines whether the command checkbox is active.
- * font		 	Caption's font name, style and size.
- * height		The height of checkbox in twips.
- * left			The number of twips from the command checkbox's left
- *			edge to the Form window's left edge.
- * mouse_ptr		The shape of the mouse cursor when the user moves the
- *			mouse over the command checkbox.
- * picture		The name of icon graphic image that appears on the
- *			command checkbox as long as the Style property is set to
- *			1-Graphical.
- * style		Determines whether the command checkbox appears as a
- *			standard Windows command checkbox (if set to 0-Standard)
- *			or a command checkbox with a color and possible picture
- *			(if set to 1-Graphical).
- * tab_index		Specifies the order of the command checkbox in the focus
- *			order.
- * tab_stop		Determines whether the command checkbox can receive the
- *			focus.
- * tool_tip_text	Holds the text that appears as a ToolTip at runtime.
- * top			Holds the number of twips from the command checkbox's
- *			top edge to the Form window's top edge.
- * visible		Determines whether the command checkbox appears or is
- *			hidden from the user.
- * width		The width of the command checkbox in twips.
- *
- * Definitions:
- * twip		1,440th of an inch (the smallest screen measurement)
- *
- */
-
 /**
  * checkbox_setarg:
  *   @ec
