@@ -32,45 +32,6 @@ typedef struct {
 	char           *real_caption;
 } GBRunCmdButton;
 
-/*
- * _GBECmdButton defines a VB Command Button
- *
- * back_color		Specifies the command button's background color.
- * cancel	 	Determines whether the command button gets a Click
- *			event if the user presses ESC.
- * caption		The text that appears on the command button.
- * def_resp		Determines if the command button respond to an Enter
- *			keypress even if another control has the focus.
- * enabled		Determines whether the command button is active.
- * font		 	Caption's font name, style and size.
- * height		The height of button in twips.
- * left			The number of twips from the command button's left
- *			edge to the Form window's left edge.
- * mouse_ptr		The shape of the mouse cursor when the user moves the
- *			mouse over the command button.
- * picture		The name of icon graphic image that appears on the
- *			command button as long as the Style property is set to
- *			1-Graphical.
- * style		Determines whether the command button appears as a
- *			standard Windows command button (if set to 0-Standard)
- *			or a command button with a color and possible picture
- *			(if set to 1-Graphical).
- * tab_index		Specifies the order of the command button in the focus
- *			order.
- * tab_stop		Determines whether the command button can receive the
- *			focus.
- * tool_tip_text	Holds the text that appears as a ToolTip at runtime.
- * top			Holds the number of twips from the command button's
- *			top edge to the Form window's top edge.
- * visible		Determines whether the command button appears or is
- *			hidden from the user.
- * width		The width of the command button in twips.
- *
- * Definitions:
- * twip		1,440th of an inch (the smallest screen measurement)
- *
- */
-
 /**
  * cmdbutton_click
  *   @button
