@@ -249,7 +249,6 @@ form_setarg (GBRunEvalContext *ec,
 	}
 }
 
-
 /**
  * form_getarg
  *   @ec
@@ -358,7 +357,9 @@ gbrun_form_pass_properties (GBRunEvalContext *ec,
 		ref.name   = prop->name;
 		ref.parms  = NULL;
 
-		if (gbrun_object_has_property (GBRUN_OBJECT_GET_CLASS (obj), prop->name))
+		if (gbrun_object_has_property (
+			GBRUN_OBJECT_GET_CLASS (obj),
+			prop->name, GBRUN_PROPERTY_WRITEABLE))
 			gb_object_assign (GB_EVAL_CONTEXT (ec), GB_OBJECT (obj),
 					  &ref, prop->value, FALSE);
 		else
@@ -611,6 +612,19 @@ gbrun_form_class_init (GBRunObjectClass *klass)
 	gbrun_object_add_property (klass, "clienttop",    gb_type_int, TOP);
 	gbrun_object_add_property (klass, "clientwidth",  gb_type_int, WIDTH);
 
+	/*
+	 * We nee the Objects collection here;
+	 */
+/*
+	This line:
+
+		Form1!Ctrl1.Text = "Hello"
+
+	translates into this code:
+
+		Form1.Controls.Item("Ctrl1").Text = "Hello"
+*/
+
 	gbrun_object_add_method_arg (
 		klass, "sub;show;modal,integer,byval,0;ownerform,variant,byref,0;g", form_show);
 
